You are viewing a plain text version of this content. The canonical link for it is here.
Posted to dev@tomcat.apache.org by ma...@apache.org on 2007/01/27 22:32:53 UTC

svn commit: r500629 - in /tomcat/tc6.0.x/trunk: java/org/apache/catalina/authenticator/ webapps/docs/

Author: markt
Date: Sat Jan 27 13:32:52 2007
New Revision: 500629

URL: http://svn.apache.org/viewvc?view=rev&rev=500629
Log:
Port fix bug 40524. request.getAuthType() now returns CLIENT_CERT rather than CLIENT-CERT as per the spec. Now only web.xml, o.a.c.deploy.LoginConfig and Authenticators.properties use CLIENT-CERT.

Modified:
    tomcat/tc6.0.x/trunk/java/org/apache/catalina/authenticator/Constants.java
    tomcat/tc6.0.x/trunk/java/org/apache/catalina/authenticator/SSLAuthenticator.java
    tomcat/tc6.0.x/trunk/java/org/apache/catalina/authenticator/SingleSignOn.java
    tomcat/tc6.0.x/trunk/java/org/apache/catalina/authenticator/SingleSignOnEntry.java
    tomcat/tc6.0.x/trunk/webapps/docs/changelog.xml

Modified: tomcat/tc6.0.x/trunk/java/org/apache/catalina/authenticator/Constants.java
URL: http://svn.apache.org/viewvc/tomcat/tc6.0.x/trunk/java/org/apache/catalina/authenticator/Constants.java?view=diff&rev=500629&r1=500628&r2=500629
==============================================================================
--- tomcat/tc6.0.x/trunk/java/org/apache/catalina/authenticator/SSLAuthenticator.java (original)
+++ tomcat/tc6.0.x/trunk/java/org/apache/catalina/authenticator/SSLAuthenticator.java Sat Jan 27 13:32:52 2007
@@ -102,7 +102,7 @@
 
         // NOTE: We don't try to reauthenticate using any existing SSO session,
         // because that will only work if the original authentication was
-        // BASIC or FORM, which are less secure than the CLIENT-CERT auth-type
+        // BASIC or FORM, which are less secure than the CLIENT_CERT auth-type
         // specified for this webapp
         //
         // Uncomment below to allow previous FORM or BASIC authentications

Modified: tomcat/tc6.0.x/trunk/java/org/apache/catalina/authenticator/SingleSignOn.java
URL: http://svn.apache.org/viewvc/tomcat/tc6.0.x/trunk/java/org/apache/catalina/authenticator/SingleSignOn.java?view=diff&rev=500629&r1=500628&r2=500629
==============================================================================
--- tomcat/tc6.0.x/trunk/java/org/apache/catalina/authenticator/SingleSignOn.java (original)
+++ tomcat/tc6.0.x/trunk/java/org/apache/catalina/authenticator/SingleSignOn.java Sat Jan 27 13:32:52 2007
@@ -616,7 +616,7 @@
      * <p>
      * The purpose of this method is to allow an SSO entry that was
      * established without a username/password combination (i.e. established
-     * following DIGEST or CLIENT-CERT authentication) to be updated with
+     * following DIGEST or CLIENT_CERT authentication) to be updated with
      * a username and password if one becomes available through a subsequent
      * BASIC or FORM authentication.  The SSO entry will then be usable for
      * reauthentication.
@@ -630,7 +630,7 @@
      * @param ssoId     identifier of Single sign to be updated
      * @param principal the <code>Principal</code> returned by the latest
      *                  call to <code>Realm.authenticate</code>.
-     * @param authType  the type of authenticator used (BASIC, CLIENT-CERT,
+     * @param authType  the type of authenticator used (BASIC, CLIENT_CERT,
      *                  DIGEST or FORM)
      * @param username  the username (if any) used for the authentication
      * @param password  the password (if any) used for the authentication

Modified: tomcat/tc6.0.x/trunk/java/org/apache/catalina/authenticator/SingleSignOnEntry.java
URL: http://svn.apache.org/viewvc/tomcat/tc6.0.x/trunk/java/org/apache/catalina/authenticator/SingleSignOnEntry.java?view=diff&rev=500629&r1=500628&r2=500629
==============================================================================
--- tomcat/tc6.0.x/trunk/java/org/apache/catalina/authenticator/SingleSignOnEntry.java (original)
+++ tomcat/tc6.0.x/trunk/java/org/apache/catalina/authenticator/SingleSignOnEntry.java Sat Jan 27 13:32:52 2007
@@ -56,7 +56,7 @@
      *
      * @param principal the <code>Principal</code> returned by the latest
      *                  call to <code>Realm.authenticate</code>.
-     * @param authType  the type of authenticator used (BASIC, CLIENT-CERT,
+     * @param authType  the type of authenticator used (BASIC, CLIENT_CERT,
      *                  DIGEST or FORM)
      * @param username  the username (if any) used for the authentication
      * @param password  the password (if any) used for the authentication
@@ -119,7 +119,7 @@
      * Gets the name of the authentication type originally used to authenticate
      * the user associated with the SSO.
      *
-     * @return "BASIC", "CLIENT-CERT", "DIGEST", "FORM" or "NONE"
+     * @return "BASIC", "CLIENT_CERT", "DIGEST", "FORM" or "NONE"
      */
     public String getAuthType() {
         return (this.authType);
@@ -170,7 +170,7 @@
      *
      * @param principal the <code>Principal</code> returned by the latest
      *                  call to <code>Realm.authenticate</code>.
-     * @param authType  the type of authenticator used (BASIC, CLIENT-CERT,
+     * @param authType  the type of authenticator used (BASIC, CLIENT_CERT,
      *                  DIGEST or FORM)
      * @param username  the username (if any) used for the authentication
      * @param password  the password (if any) used for the authentication

Modified: tomcat/tc6.0.x/trunk/webapps/docs/changelog.xml
URL: http://svn.apache.org/viewvc/tomcat/tc6.0.x/trunk/webapps/docs/changelog.xml?view=diff&rev=500629&r1=500628&r2=500629
==============================================================================
--- tomcat/tc6.0.x/trunk/webapps/docs/changelog.xml (original)
+++ tomcat/tc6.0.x/trunk/webapps/docs/changelog.xml Sat Jan 27 13:32:52 2007
@@ -35,6 +35,12 @@
         created during a secure request. Patch provided by Chris Halstead.
         (markt)
       </fix>
+      <fix>
+        <bug>40524</bug>: HttpServletRequest.getAuthType() now returns
+        CLIENT_CERT rather than CLIENT-CERT for certificate authentication
+        as per the spec. Note that web.xml continues to use CLIENT-CERT to
+        specify the certificate authentication should be used. (markt)
+      </fix>
     </changelog>
   </subsection>
   <subsection name="Jasper">



---------------------------------------------------------------------
To unsubscribe, e-mail: dev-unsubscribe@tomcat.apache.org
For additional commands, e-mail: dev-help@tomcat.apache.org
--- tomcat/tc6.0.x/trunk/java/org/apache/catalina/authenticator/Constants.java (original)
+++ tomcat/tc6.0.x/trunk/java/org/apache/catalina/authenticator/Constants.java Sat Jan 27 13:32:52 2007
@@ -25,7 +25,7 @@
 
     // Authentication methods for login configuration
     public static final String BASIC_METHOD = "BASIC";
-    public static final String CERT_METHOD = "CLIENT-CERT";
+    public static final String CERT_METHOD = "CLIENT_CERT";
     public static final String DIGEST_METHOD = "DIGEST";
     public static final String FORM_METHOD = "FORM";
 
@@ -55,7 +55,7 @@
      * or not any user has been authenticated:</p>
      * <ul>
      * <li><strong>request.getAuthType()</strong>
      *     will return BASIC, CLIENT-CERT, DIGEST, FORM, or <code>null</code>
      *     if there is no authenticated user.</li>
      * <li><strong>request.getUserPrincipal()</strong>
      *     will return the authenticated <code>Principal</code> returned by the
@@ -55,7 +55,7 @@
      * <ul>
      * <li><strong>request.getAuthType()</strong>
-     *     will return BASIC, CLIENT-CERT, DIGEST, FORM, or <code>null</code>
+     *     will return BASIC, CLIENT_CERT, DIGEST, FORM, or <code>null</code>
      *     if there is no authenticated user.</li>
      * <li><strong>request.getUserPrincipal()</strong>

Modified: tomcat/tc6.0.x/trunk/java/org/apache/catalina/authenticator/SSLAuthenticator.java
URL: http://svn.apache.org/viewvc/tomcat/tc6.0.x/trunk/java/org/apache/catalina/authenticator/SSLAuthenticator.java?view=diff&rev=500629&r1=500628&r2=500629
==============================================================================